<?php
// MoWiKi: gьWikiN[
// Author: Yuki "Randolph" Okada

/*-
 * Copyright (c) 2004 Yuki Okada
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

// gѓƎ̋@\ꂽB
// ƂɂgтŎg₷悤ɁB

// f[^́At@Cencodeꂽy[W^CgȃeLXgt@Cɓ悤B
// XV`FbNmtime悤B

// jFƂ肠Ăl悤B
// ʂɃIuWFNgwłłłB

// Wiki̍\猾āA[œe͖ȁB

// ݒt@Cǂݍ
require('mowiki-ini.php');

// ֐t@Cǂݍ
require('func.php');

// 
require($MOWIKI_LIB.'input.php');

// gюʔ
require($MOWIKI_LIB.'carrier.php');

// y[Wꗗ擾(Azzɓ)
// require($MOWIKI_LIB.'content_list.php');

if ($gIn['a'] == 'L') { // ꗗ[h̏ꍇ
  // ꗗƃgbv𓯈ꎋĂB
  // ꗗ=gbvȂAڎwy[Wɍŝ͊yǁAgbvҏWłȂB
  // ꗗ!=gbvȂAgbvҏWł邯ǁAڎwy[Wɍŝ͂߂ǂB
  // Ƃ肠ꗗ=gbvŎĂ݂悤B
  require($MOWIKI_LIB.'content_list.php');

} else if ($gIn['a'] == 'S') { // y[Wۑ[h̏ꍇ

  // ͂0oCgȂAt@C폜B
  // gbv͏ꂽ炦炢ƂɂȂ̂ŋ֎~B
  if ((strlen($gIn['body']) == '0') && (decode($gIn['title']) != $MOWIKI_FRONTPAGE)) {
	
	$filename = $MOWIKI_DATA.$gIn['title'].'.txt';
	
	if (file_exists($filename)) {
	  unlink($filename);
	}

	require($MOWIKI_LIB.'content_list.php');
	
  } else {
	// f[^ۑ
	require($MOWIKI_LIB.'update.php');

	// y[Wĕ\
	require($MOWIKI_LIB.'render.php');
	$gOut['edit'] = 1;
  }
  
} else if ($gIn['a'] == 'N') { // VK쐬[h̏ꍇ
  
  // y[WƓe͂Ăꍇ
  if ((strlen($gIn['title']) > 0)
	  && (strlen($gIn['body']) > 0)) {

	require($MOWIKI_LIB.'update.php');

  } else if (strlen($gIn['title']) > 0) {
	// y[W͂Ăꍇ

	// e̓tH[\
	require($MOWIKI_LIB.'edit.php');

  } else { // VKy[W쐬tH[\
	require($MOWIKI_LIB.'newpage.php');
  }
  
} else if ($gIn['a'] == 'M') { // ҏW[h̏ꍇ
  // e̓tH[\
  require($MOWIKI_LIB.'edit.php');

} else if ($gIn['a'] == 'D') { // 폜[h̏ꍇ
  // 폜mFhtml\
  
} else { // wy[W\[h̏ꍇ
  if (strlen($gIn['title']) == '0') {
	$gIn['title'] = encode($MOWIKI_FRONTPAGE);
  }
  
  // y[W\
  require($MOWIKI_LIB.'render.php');
  $gOut['edit'] = 1;
  
}

require($MOWIKI_VIEW.'template.php');
?>